




## Create new Configuration

```shell
```



### Using Parameters

`pam config new -g TCDth67bSkqp0Gu-6WlqYQ -cn "Prod AWS Rotation Creds" -ct "aws" -cp v165TFXM2WpNj5lwNn1SEg -cr B2VHZ16mGDWhNpqAPxChhA -cr UIs2POKxWX81PjtbZQ1mOg`

- `--config-name`, `-cn` Configuration name
- `--config-type`, `-ct` Configuration Type. Can be one of `aws`, `azure`, `local`
- `--config-primary-access-record-uid`, `-cp` Access Record UID 
- `--config-resource-records`, `-cr` Resource Record UIDs
- `--config-record-types`, `-cy` Record types that the action will be performed against
- `--config-default-schedule`, `-cd` Default Scheduler